@@ -1,10 +1,6 @@
 use solana_program::{account_info::AccountInfo, program_error::ProgramError, pubkey::Pubkey};
 
-use crate::{
-    error::MetadataError,
-    state::{UseAuthorityRecord, UseMethod, Uses, PREFIX, USER},
-    utils::assert_derivation,
-};
+use crate::{error::MetadataError, pda, state::{UseAuthorityRecord, UseMethod, Uses, PREFIX, USER}, utils::assert_derivation};
 
 pub fn assert_valid_use(
     incoming_use: &Option<Uses>,
@@ -14,7 +10,7 @@ pub fn assert_valid_use(
         if i.use_method == UseMethod::Single && (i.total != 1 || i.remaining != 1) {
             return Err(MetadataError::InvalidUseMethod.into());
         }
-        if i.use_method == UseMethod::Multiple && i.total < 2 {
+        if i.use_method == UseMethod::Multiple && (i.total < 2 || i.total < i.remaining) {
             return Err(MetadataError::InvalidUseMethod.into());
         }
     }
@@ -35,6 +31,14 @@ pub fn assert_valid_use(
     };
 }
 
+pub fn assert_burner(program_as_burner: &Pubkey) -> Result<u8, MetadataError> {
+    let (canon_burn, b) = pda::find_program_as_burner_account();
+    if &canon_burn != program_as_burner {
+        return Err(MetadataError::DerivedKeyInvalid.into());
+    }
+    Ok(b)
+}
+
 pub fn assert_valid_bump(
     canonical_bump: u8,
     use_authority_record: &UseAuthorityRecord,
@@ -50,7 +54,7 @@ pub fn assert_use_authority_derivation(
     use_authority_record_info: &AccountInfo,
     user_info: &AccountInfo,
     mint_info: &AccountInfo,
-) -> Result<u8, ProgramError>{
+) -> Result<u8, ProgramError> {
     let use_authority_seeds = [
         PREFIX.as_bytes(),
         program_id.as_ref(),
